/*
 * Interface file: Unix Console -> Curses
 * Nils M Holm, 2024
 * Public Domain / 0BSD License
 */

#include <curses.h>
#include <unistd.h>

#define cell	long

void t3x_setup(cell p) {
	initscr();
	raw();
	noecho();
	scrollok(stdscr, TRUE);
}

void t3x_shutdown(void) {
	refresh();
	echo();
	noraw();
	endwin();
}

void t3x_clrscr(void) {
	clear();
}

void t3x_clreol(void) {
	clrtoeol();
}

void t3x_move(cell x, cell y) {
	move(x, y);
}

void t3x_scroll(void) {
	scroll(stdscr);
	refresh();
}

void t3x_rscroll(void) {
	wscrl(stdscr, -1);
	refresh();
}

void t3x_refresh(void) {
	refresh();
}

cell t3x_getkey(void) {
	int	c;

	c = getch();
	return c == '\n'? '\r': c;
}

cell t3x_pollkey(void) {
	int	c;

	nodelay(stdscr, TRUE);
	c = getch();
	nodelay(stdscr, FALSE);
	return c == ERR? 0: c == '\n'? '\r': c;
}

void t3x_wrch(cell c) {
	addch(c);
}

void t3x_writes(char *s) {
	addstr(s);
}

void t3x_standout(void) {
	standout();
}

void t3x_normal(void) {
	standend();
}

static int	Mdelay = 1000;

void t3x_calibrate(cell m) {
	Mdelay = m;
}

void t3x_wait(cell hs) {
	refresh();
	usleep(hs * Mdelay);
}
